@@ -49,8 +49,10 @@ class SearchConnection(object):
         of the ESGF search service excluding the final endpoint name.
         Usually this is http://<hostname>/esg-search
     :ivar distrib: Boolean stating whether searches through this connection are
-        distributed.  I.e. whether the Search service distributes the query to
-        other search peers.
+        distributed.  i.e. whether the Search service distributes the query to
+        other search peers.  See also the documentation for the ``facets``
+        argument to ``pyesgf.search.context.SearchContext`` in relation to
+        distributed searches.
     :ivar cache: Path to `sqlite` cache file. Cache expires every hours.
     :ivar timeout: Time (in seconds) before query returns an error.
                    Default: 120s.
@@ -95,7 +97,7 @@ class SearchConnection(object):
 
     def open(self):
         if (isinstance(self._passed_session, requests.Session) or isinstance(
-                self._passed_session, requests_cache.core.CachedSession)):
+                self._passed_session, requests_cache.CachedSession)):
             self.session = self._passed_session
         else:
             self.session = create_single_session(
@@ -115,7 +117,7 @@ class SearchConnection(object):
     def close(self):
         # Close the session
         if not (isinstance(self._passed_session, requests.Session) or isinstance(
-                self._passed_session, requests_cache.core.CachedSession)):
+                self._passed_session, requests_cache.CachedSession)):
             self.session.close()
         self._isopen = False
         return
@@ -361,7 +363,7 @@ def create_single_session(cache=None, expire_after=datetime.timedelta(hours=1),
     """
     if cache is not None:
         try:
-            session = (requests_cache.core
+            session = (requests_cache
                        .CachedSession(cache,
                                       expire_after=expire_after))
         except DatabaseError:
@@ -370,7 +372,7 @@ def create_single_session(cache=None, expire_after=datetime.timedelta(hours=1),
                 os.remove(cache)
             except Exception:
                 pass
-            session = (requests_cache.core
+            session = (requests_cache
                        .CachedSession(cache, expire_after=expire_after))
     else:
         session = requests.Session()
